module.exports = defineTest({
	description: 'allow calls to pure static methods to be tree-shaken'
});
